summaryrefslogtreecommitdiff
path: root/modules
diff options
context:
space:
mode:
authorwebchick <webchick@24967.no-reply.drupal.org>2011-03-28 08:39:48 -0700
committerwebchick <webchick@24967.no-reply.drupal.org>2011-03-28 08:39:48 -0700
commite7390c50b545d8577bcca7f212f29aec7c2f1cfc (patch)
tree5a42e7e7f068e5d72c8389a2d86b22f62689ffc3 /modules
parentf1ba363a8c3b5185e4e663bd2c3b7eb7b0fb9983 (diff)
downloadbrdo-e7390c50b545d8577bcca7f212f29aec7c2f1cfc.tar.gz
brdo-e7390c50b545d8577bcca7f212f29aec7c2f1cfc.tar.bz2
Issue #1097972 by boombatower: Fixed hook_field_extra_fields_display_alter() incorrect example code.
Diffstat (limited to 'modules')
-rw-r--r--modules/field/field.api.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/modules/field/field.api.php b/modules/field/field.api.php
index 1b3290f67..f905fa060 100644
--- a/modules/field/field.api.php
+++ b/modules/field/field.api.php
@@ -15,7 +15,7 @@
*
* Fieldable entities or modules that want to have their components supported
* should expose them using this hook. The user-defined settings (weight,
* visibility) are automatically applied on rendered forms and displayed
* entities in a #pre_render callback added by field_attach_form() and
* field_attach_view().
*
@@ -2204,7 +2204,7 @@ function hook_field_display_ENTITY_TYPE_alter(&$display, $context) {
*/
function hook_field_extra_fields_display_alter(&$displays, $context) {
if ($context['entity_type'] == 'taxonomy_term' && $context['view_mode'] == 'full') {
- $displays['description']['visibility'] = FALSE;
+ $displays['description']['visible'] = FALSE;
}
}
@@ -15,7 +15,7 @@
* Fieldable entities or modules that want to have their components supported
* should expose them using this hook. The user-defined settings (weight,
- * visibility) are automatically applied on rendered forms and displayed
+ * visible) are automatically applied on rendered forms and displayed
* entities in a #pre_render callback added by field_attach_form() and
* field_attach_view().